@@ -1,8 +1,8 @@
 /*
 **  OSSP ex - Exception Handling
-**  Copyright (c) 2002-2003 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2002-2003 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2002-2003 Cable & Wireless Deutschland <http://www.cw.com/de/>
+**  Copyright (c) 2002-2004 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2004 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2002-2004 Cable & Wireless <http://www.cw.com/>
 **
 **  This file is part of OSSP ex, an exception handling library
 **  which can be found at http://www.ossp.org/pkg/lib/ex/.
@@ -34,7 +34,7 @@
 /* required ISO-C standard facilities */
 #include <stdio.h>
 
-/* convinience define */
+/* convenience define */
 #ifndef NULL
 #define NULL (void *)0
 #endif
@@ -82,13 +82,13 @@ typedef struct { __ex_mctx_struct } __ex_mctx_t;
 /* declare the exception type (public) */
 typedef struct {
     /* throw value */
-    void *ex_class;
-    void *ex_object;
-    void *ex_value;
+    void       *ex_class;
+    void       *ex_object;
+    void       *ex_value;
     /* throw point */
-    char *ex_file;
-    int   ex_line;
-    char *ex_func;
+    const char *ex_file;
+    int         ex_line;
+    const char *ex_func;
 } ex_t;
 
 /* declare the context type (private) */
@@ -100,13 +100,12 @@ typedef struct {
     int           ctx_shielding;/* permanent counter of exception shielding level */
     int           ctx_shield;   /* temporary flag for exception shielding macro */
     int           ctx_caught;   /* temporary flag whether exception was caught */
-    int           ctx_cleanup;  /* temporary flag whether cleanup block was present */
     volatile ex_t ctx_ex;       /* temporary exception storage */
 } ex_ctx_t;
 
 /* the static and dynamic initializers for a context structure */
 #define EX_CTX_INITIALIZER \
-    { NULL, 0, 0, 0, 0, 0, 0, 0, { NULL, NULL, NULL, NULL, 0, NULL } }
+    { NULL, 0, 0, 0, 0, 0, 0, { NULL, NULL, NULL, NULL, 0, NULL } }
 #define EX_CTX_INITIALIZE(ctx) \
     do { \
         (ctx)->ctx_mctx         = NULL; \
@@ -116,7 +115,6 @@ typedef struct {
         (ctx)->ctx_shielding    = 0;    \
         (ctx)->ctx_shield       = 0;    \
         (ctx)->ctx_caught       = 0;    \
-        (ctx)->ctx_cleanup      = 0;    \
         (ctx)->ctx_ex.ex_class  = NULL; \
         (ctx)->ctx_ex.ex_object = NULL; \
         (ctx)->ctx_ex.ex_value  = NULL; \
@@ -139,11 +137,11 @@ extern void __ex_terminate_default(ex_t *e);
 #define ex_try \
     { \
         ex_ctx_t *__ex_ctx_ptr = __ex_ctx(); \
+        int __ex_cleanup = 0; \
         __ex_mctx_t *__ex_mctx_en; \
         __ex_mctx_t __ex_mctx_me; \
         __ex_mctx_en = __ex_ctx_ptr->ctx_mctx; \
         __ex_ctx_ptr->ctx_mctx = &__ex_mctx_me; \
-        __ex_ctx_ptr->ctx_cleanup = 0; \
         if (__ex_mctx_save(&__ex_mctx_me)) { \
             if (1)
 
@@ -158,7 +156,7 @@ extern void __ex_terminate_default(ex_t *e);
             __ex_ctx_ptr->ctx_caught = 1; \
         } \
         __ex_ctx_ptr->ctx_mctx = __ex_mctx_en; \
-        __ex_ctx()->ctx_cleanup = 1; \
+        __ex_cleanup = 1; \
         if (1) { \
             if (1)
 
@@ -166,11 +164,11 @@ extern void __ex_terminate_default(ex_t *e);
 #define ex_catch(e) \
             else { \
             } \
-            if (!(__ex_ctx()->ctx_cleanup)) \
+            if (!(__ex_cleanup)) \
                 __ex_ctx_ptr->ctx_caught = 0; \
         } \
         else { \
-            if (!(__ex_ctx()->ctx_cleanup)) { \
+            if (!(__ex_cleanup)) { \
                 __ex_mctx_restored(&__ex_mctx_me); \
                 __ex_ctx_ptr->ctx_caught = 1; \
             } \
